/**
 * presentation init
 */

/**
 * @returns {boolean}
 */
function inIframe () {
    try {
        return window.self !== window.top;
    } catch (e) {
        return true;
    }
}

var loc = window.location.toString();

if (!inIframe() && loc.indexOf('presentation=1') < 0) {
    // umleitung
    if (loc.indexOf('?') >= 0) {
        window.location = window.location + '&presentation=1';
    } else {
        window.location = window.location + '?presentation=1';
    }

} else {

    window.addEvent('domready', function () {
        "use strict";

        if (inIframe()) {
            return;
        }

        var Display = new Element('div', {
            'class': 'presentation-display'
        }).inject(document.body);

        var Container = new Element('div', {
            'class': 'presentation-display-container'
        }).inject(Display);

        var loc = window.location.toString().replace('presentation=1', '');

        if (window.location.hash !== '') {
            loc = window.location.protocol;
            loc = loc + '//' + window.location.host;
            loc = loc + window.location.hash.replace('#', '');
        }

        var iFrame = new Element('iframe', {
            src        : loc,
            frameborder: 0
        }).inject(Container);

        iFrame.onload = function () {
            window.top.location = '#' + iFrame.contentWindow.window.location.pathname;
        };

        var Bar = new Element('div', {
            'class': 'presentation-bar',
            html   : '<div class="presentation-bar-buttons">' +
                     '    <button class="desktop active">Desktop</button>' +
                     '    <button class="tablet">Tablet</button>' +
                     '    <button class="tablet_portrait">Tablet (Porttrait)</button>' +
                     '    <button class="mobile">Mobile</button>' +
                     '</div>'
        }).inject(document.body);


        var changeFrame = function (height, width) {
            var top = 40;

            if (height == '100%' && width == '100%') {
                top = 0;

                Container.removeClass('presentation-display-container-shadow');
                Display.setStyle('overflow', null);
            } else {
                Container.addClass('presentation-display-container-shadow');
                Display.setStyle('overflow', 'auto');
            }

            var Hiding = new Element('div', {
                'class': 'presentation-display-container-hiding',
                styles : {
                    opacity: 0
                }
            }).inject(Container);

            moofx(Hiding).animate({
                opacity: 1
            }, {
                duration: 200,
                callback: function () {
                    moofx(Container).animate({
                        height: height,
                        width : width,
                        top   : top
                    }, {
                        duration: 200,
                        callback: function () {
                            moofx(Hiding).animate({
                                opacity: 0
                            }, {
                                duration: 200,
                                callback: function () {
                                    Hiding.destroy();
                                }
                            });
                        }
                    });
                }
            });
        };

        var resetButtons = function () {
            Bar.getElements('button').removeClass('active');
        };

        var showDesktop = function () {
            resetButtons();
            this.addClass('active');

            changeFrame('100%', '100%');
        };

        var showTablet = function () {
            resetButtons();
            this.addClass('active');

            changeFrame(768, 1024);
        };

        var showTabletPortait = function () {
            resetButtons();
            this.addClass('active');

            changeFrame(1024, 768);
        };

        var showMobile = function () {
            resetButtons();
            this.addClass('active');

            changeFrame(600, 360);
        };

        Bar.getElement('.desktop').addEvent('click', showDesktop);
        Bar.getElement('.tablet').addEvent('click', showTablet);
        Bar.getElement('.tablet_portrait').addEvent('click', showTabletPortait);
        Bar.getElement('.mobile').addEvent('click', showMobile);
    });
}
